﻿<?xml version="1.0" encoding="utf-8" standalone="yes"?>
<!-- Mapcam.info Garmin GPX output fixer & filter by warnings type -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                xmlns:gpx="http://www.topografix.com/GPX/1/1" xmlns:gpxx="http://www.garmin.com/xmlschemas/GpxExtensions/v3"
                exclude-result-prefixes="gpx">
    <xsl:output method="xml" encoding="utf-8" indent="yes" standalone="yes"/>

    <!-- Warning type Id to filter source speedcam.gpx; should be overridden externally -->
    <xsl:param name="WarningTypeId">1</xsl:param>
    
    <!-- Warning tag name; could be overridden externally -->
    <xsl:param name="WarningTagName">
        <xsl:choose>
            <xsl:when test="$WarningTypeId=1">Radar</xsl:when>
            <xsl:when test="$WarningTypeId=2">Radar-traffic light</xsl:when>
            <xsl:when test="$WarningTypeId=3">Radar (red light)</xsl:when>
            <xsl:when test="$WarningTypeId=4">Radar (pair)</xsl:when>
            <xsl:when test="$WarningTypeId=5">Mobile radar</xsl:when>
            <xsl:when test="$WarningTypeId=20">Stationary post</xsl:when>
            <xsl:when test="$WarningTypeId=21">Railroad crossing</xsl:when>
            <xsl:when test="$WarningTypeId=22">School</xsl:when>
            <xsl:when test="$WarningTypeId=100">Built-up area</xsl:when>
            <xsl:when test="$WarningTypeId=101">Speed control</xsl:when>
            <xsl:when test="$WarningTypeId=102">Speed bump</xsl:when>
            <xsl:when test="$WarningTypeId=103">Bad road</xsl:when>
            <xsl:when test="$WarningTypeId=104">Dangerous turn</xsl:when>
            <xsl:when test="$WarningTypeId=105">Dangerous crossroad</xsl:when>
            <xsl:when test="$WarningTypeId=106">Other danger</xsl:when>
        </xsl:choose>
    </xsl:param>

    <!-- Add speed suffix to warning audio file name; have 0 or 1 values; could be overridden externally -->
    <xsl:param name="AddSpeedToWarningAudioFileName">
        <xsl:choose>
            <xsl:when test="$WarningTypeId=1">1</xsl:when>
            <xsl:when test="$WarningTypeId=101">1</xsl:when>
            <xsl:otherwise>0</xsl:otherwise>
        </xsl:choose>
    </xsl:param>

    <xsl:template match="/">
        <xsl:apply-templates select="gpx:gpx"/>
    </xsl:template>

    <xsl:template match="gpx:gpx">
        <xsl:copy>
            <xsl:copy-of select="@creator"/>
            <xsl:copy-of select="@version"/>
            <xsl:attribute name="schemaLocation" namespace="http://www.w3.org/2001/XMLSchema-instance">http://www.topografix.com/GPX/1/1 http://www.topografix.com/GPX/1/1/gpx.xsd http://www.garmin.com/xmlschemas/GpxExtensions/v3 http://www.garmin.com/xmlschemas/GpxExtensions/v3/GpxExtensionsv3.xsd</xsl:attribute>
            <xsl:copy-of select="gpx:metadata"/>
            <xsl:apply-templates select="gpx:wpt[gpx:link/@href=concat($WarningTypeId, '.bmp') or starts-with(gpx:link/@href, concat($WarningTypeId, '_'))]"/>
        </xsl:copy>
    </xsl:template>

    <xsl:template match="gpx:wpt">
        <xsl:copy>
            <xsl:copy-of select="@lat"/>
            <xsl:copy-of select="@lon"/>
            <xsl:apply-templates select="gpx:name"/>
            <xsl:apply-templates select="gpx:cmt"/>
            <xsl:apply-templates select="gpx:desc"/>
            <xsl:apply-templates select="gpx:link[substring-after(@href, '.')='bmp']"/>
            <xsl:copy-of select="gpx:sym"/>
            <xsl:copy-of select="gpx:extensions"/>
        </xsl:copy>
    </xsl:template>

    <xsl:template match="gpx:name">
        <!-- Cut underscore from name and fix russian 'Speed bump' name -->
        <xsl:variable name="name" select="translate(., '_', ' ')"/>
        <xsl:copy>
            <xsl:choose>
                <xsl:when test="contains($name, 'полицейски@')">
                    <xsl:value-of select="substring-before($name,'полицейски@')"/>
                    <xsl:text>полицейский@</xsl:text>
                    <xsl:value-of select="substring-after($name,'полицейски@')"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$name"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:copy> 
    </xsl:template>

    <xsl:template match="gpx:cmt">
        <!-- Cut tag name in brackets from user comment string -->
        <xsl:copy>
            <xsl:value-of select="normalize-space(substring-after(., ']'))"/>
        </xsl:copy>
    </xsl:template>

    <xsl:template match="gpx:desc">
        <!-- Insert appropriate tag and cut user comments -->
        <xsl:if test="string-length($WarningTagName) &gt; 0">
            <xsl:variable name="speed" select="substring-after(../gpx:name, '@')"/>
            <xsl:copy>
                <xsl:text>[</xsl:text>
                <xsl:value-of select="$WarningTagName"/>
                <xsl:text> </xsl:text>
                <xsl:value-of select="$speed"/>
                <xsl:text> km/h]</xsl:text> <!-- TODO Use 'kph' units name? -->
            </xsl:copy>
        </xsl:if>
    </xsl:template>

    <xsl:template match="gpx:link">
        <!-- Create two 'link' elements with references to .bmp and .wav files -->
        <xsl:variable name="speed" select="substring-after(../gpx:name, '@')"/>
        <xsl:copy>
            <xsl:copy-of select="@href"/>
        </xsl:copy>
        <xsl:copy>
            <xsl:attribute name="href">
                <xsl:value-of select="$WarningTypeId"/>
                <xsl:if test="$AddSpeedToWarningAudioFileName=1">
                    <xsl:text>_</xsl:text>
                    <xsl:value-of select="$speed"/>
                </xsl:if>
                <xsl:text>.wav</xsl:text>
            </xsl:attribute>
        </xsl:copy>
    </xsl:template>

</xsl:stylesheet>
